pub type PR_GlobalSetupFunc = Option<unsafe extern "C" fn(in_dataP: *const PR_InData, global_contextH: PR_GlobalContextH, global_dataPH: *mut PR_GlobalDataH) -> A_Err>;Expand description
called after main. This happens just once, after the plugin is loaded. The global data is common across all instances of the plugin
Aliased Type
pub enum PR_GlobalSetupFunc {
None,
Some(unsafe extern "C" fn(*const PR_InData, *mut *mut PR_GlobalContext, *mut *mut *mut _Up_OpaqueMem) -> i32),
}